# Navigating Our Tutorial Notebooks

The following notebooks showcase examples of how you can use `jarvAIs` for classification, regression, and survival tasks!  

All of the notebooks below use clinical data from [RADCURE](https://www.cancerimagingarchive.net/collection/radcure/).  

    The RADCURE dataset was collected clinically for radiation therapy treatment 
    planning and retrospectively reconstructed for quantitative imaging research.  

### Accessing the Data  
You can find the raw and processed clinical data **[here](https://github.com/pmcdi/jarvais/tree/main/data).**  

### Data Processing  
The following function was used to process the raw data:

::: jarvais.utils.process_RADCURE_clinical
    options:
        show_docstring_description: false
        show_root_toc_entry: false
            
